==> scitools-iris-3.1.0.tar.gz: scitools-iris-3.1.0/README.md <==
<h1 align="center">
  <a href="https://scitools-iris.readthedocs.io/en/latest/">
   <img src="https://scitools-iris.readthedocs.io/en/latest/_static/iris-logo-title.png" alt="Iris" width="300"></a><br>
</h1>


<h4 align="center">
    Iris is a powerful, format-agnostic, community-driven Python package for
    analysing and visualising Earth science data
</h4>

<p align="center">
<a href="https://cirrus-ci.com/github/SciTools/iris">
<img src="https://api.cirrus-ci.com/github/SciTools/iris.svg?branch=main"
     alt="Cirrus-CI"></a>
<a href="https://scitools-iris.readthedocs.io/en/latest/?badge=latest">
<img src="https://readthedocs.org/projects/scitools-iris/badge/?version=latest"
     alt="Documentation Status"></a>
<a href="https://results.pre-commit.ci/latest/github/SciTools/iris/main">
<img src="https://results.pre-commit.ci/badge/github/SciTools/iris/main.svg"
     alt="pre-commit.ci status"></a>
<a href="https://anaconda.org/conda-forge/iris">
<img src="https://img.shields.io/conda/v/conda-forge/iris?color=orange&label=conda-forge%7Ciris&logo=conda-forge&logoColor=white"
     alt="conda-forge"></a>
<a href="https://pypi.org/project/scitools-iris">
<img src="https://img.shields.io/pypi/v/scitools-iris?color=orange&label=pypi%7Cscitools-iris&logo=python&logoColor=white"
     alt="pypi"></a>
<a href="https://github.com/SciTools/iris/releases">
<img src="https://img.shields.io/github/v/release/scitools/iris"
     alt="latest release"></a>
<a href="https://github.com/SciTools/iris/commits/main">
<img src="https://img.shields.io/github/commits-since/SciTools/iris/latest.svg"
     alt="Commits since last release"></a>
<a href="https://zenodo.org/badge/latestdoi/5312648">
<img src="https://zenodo.org/badge/5312648.svg"
     alt="zenodo"></a>
<a href="https://github.com/psf/black">
<img src="https://img.shields.io/badge/code%20style-black-000000.svg"
     alt="black"></a>
<a href="https://github.com/SciTools/iris/discussions">
<img src="https://img.shields.io/badge/github-discussions-yellow?style=social&logo=github&style=plastic"
     alt="github discussions"></a>
<a href="https://twitter.com/scitools_iris">
<img src="https://img.shields.io/twitter/follow/scitools_iris?color=yellow&label=twitter%7Cscitools_iris&logo=twitter&style=plastic"
     alt="twitter scitools_iris"></a>
</p>

<p align="center">
For documentation see the 
<a href="https://scitools-iris.readthedocs.io/en/latest/">latest</a>  
developer version or the most recent released
<a href="https://scitools-iris.readthedocs.io/en/stable/">stable</a> version.
</p>

==> scitools-iris-3.3.0rc0.tar.gz: scitools-iris-3.3.0rc0/README.md <==
<h1 align="center">
  <a href="https://scitools-iris.readthedocs.io/en/latest/">
   <img src="https://scitools-iris.readthedocs.io/en/latest/_static/iris-logo-title.svg" alt="Iris" width="300"></a><br>
</h1>


<h4 align="center">
    Iris is a powerful, format-agnostic, community-driven Python package for
    analysing and visualising Earth science data
</h4>

<p align="center">
<a href="https://github.com/SciTools/iris/actions/workflows/ci-tests.yml">
<img src="https://github.com/SciTools/iris/actions/workflows/ci-tests.yml/badge.svg?branch=main"
     alt="ci-tests"></a>
<a href="https://scitools-iris.readthedocs.io/en/latest/?badge=latest">
<img src="https://readthedocs.org/projects/scitools-iris/badge/?version=latest"
     alt="Documentation Status"></a>
<a href="https://results.pre-commit.ci/latest/github/SciTools/iris/main">
<img src="https://results.pre-commit.ci/badge/github/SciTools/iris/main.svg"
     alt="pre-commit.ci status"></a>
</p>

<p align="center">
<a href="https://anaconda.org/conda-forge/iris">
<img src="https://img.shields.io/conda/v/conda-forge/iris?color=orange&label=conda-forge%7Ciris&logo=conda-forge&logoColor=white"
     alt="conda-forge"></a>
<a href="https://pypi.org/project/scitools-iris">
<img src="https://img.shields.io/pypi/v/scitools-iris?color=orange&label=pypi%7Cscitools-iris&logo=python&logoColor=white"
     alt="pypi"></a>
<a href="https://github.com/SciTools/iris/releases">
<img src="https://img.shields.io/github/v/release/scitools/iris"
     alt="latest release"></a>
<a href="https://github.com/SciTools/iris/commits/main">
<img src="https://img.shields.io/github/commits-since/SciTools/iris/latest.svg"
     alt="Commits since last release"></a>
<a href="https://zenodo.org/badge/latestdoi/5312648">
<img src="https://zenodo.org/badge/5312648.svg"
     alt="zenodo"></a>
<a href="https://github.com/psf/black">
<img src="https://img.shields.io/badge/code%20style-black-000000.svg"
     alt="black"></a>
<a href="https://github.com/SciTools/iris/discussions">
<img src="https://img.shields.io/badge/github-discussions-yellow?style=social&logo=github&style=plastic"
     alt="github discussions"></a>
<a href="https://twitter.com/scitools_iris">
<img src="https://img.shields.io/twitter/follow/scitools_iris?color=yellow&label=twitter%7Cscitools_iris&logo=twitter&style=plastic"
     alt="twitter scitools_iris"></a>
</p>

<p align="center">
For documentation see the 
<a href="https://scitools-iris.readthedocs.io/en/latest/">latest</a>  
developer version or the most recent released
<a href="https://scitools-iris.readthedocs.io/en/stable/">stable</a> version.
</p>
